# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/common/v1/common_v1.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/common/v1/common_v1.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dnds/common/v1/common_v1.proto\x12\rnds.common.v1\"\x7f\n\x0eRequestContext\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12\'\n\x0fidempotency_key\x18\x02 \x01(\tR\x0eidempotencyKey\x12%\n\x0e\x63orrelation_id\x18\x03 \x01(\x0cR\rcorrelationId\"\xc1\x02\n\x0b\x45rrorStatus\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x38\n\x08\x63\x61tegory\x18\x03 \x01(\x0e\x32\x1c.nds.common.v1.ErrorCategoryR\x08\x63\x61tegory\x12\x41\n\x07\x64\x65tails\x18\x04 \x03(\x0b\x32\'.nds.common.v1.ErrorStatus.DetailsEntryR\x07\x64\x65tails\x12\x33\n\x13retry_after_seconds\x18\x05 \x01(\x05H\x00R\x11retryAfterSeconds\x88\x01\x01\x1a:\n\x0c\x44\x65tailsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x16\n\x14_retry_after_seconds*\xbe\x01\n\rErrorCategory\x12\x1e\n\x1a\x45RROR_CATEGORY_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45RROR_CATEGORY_RETRYABLE\x10\x01\x12\x1b\n\x17\x45RROR_CATEGORY_CONFLICT\x10\x02\x12\x19\n\x15\x45RROR_CATEGORY_POLICY\x10\x03\x12\x1d\n\x19\x45RROR_CATEGORY_VALIDATION\x10\x04\x12\x18\n\x14\x45RROR_CATEGORY_FATAL\x10\x05\x42\xd7\x01\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.common.v1B\rCommonV1ProtoP\x01Z6github.com/misty4119/nds-api/Go/nds/common/v1;commonv1\xa2\x02\x03NCX\xaa\x02\rNds.Common.V1\xca\x02\rNds\\Common\\V1\xe2\x02\x19Nds\\Common\\V1\\GPBMetadata\xea\x02\x0fNds::Common::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.common.v1.common_v1_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.common.v1B\rCommonV1ProtoP\001Z6github.com/misty4119/nds-api/Go/nds/common/v1;commonv1\242\002\003NCX\252\002\rNds.Common.V1\312\002\rNds\\Common\\V1\342\002\031Nds\\Common\\V1\\GPBMetadata\352\002\017Nds::Common::V1'
  _globals['_ERRORSTATUS_DETAILSENTRY']._loaded_options = None
  _globals['_ERRORSTATUS_DETAILSENTRY']._serialized_options = b'8\001'
  _globals['_ERRORCATEGORY']._serialized_start=502
  _globals['_ERRORCATEGORY']._serialized_end=692
  _globals['_REQUESTCONTEXT']._serialized_start=48
  _globals['_REQUESTCONTEXT']._serialized_end=175
  _globals['_ERRORSTATUS']._serialized_start=178
  _globals['_ERRORSTATUS']._serialized_end=499
  _globals['_ERRORSTATUS_DETAILSENTRY']._serialized_start=417
  _globals['_ERRORSTATUS_DETAILSENTRY']._serialized_end=475
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/sync/v1/sync.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/sync/v1/sync.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nds.common.v1 import common_v1_pb2 as nds_dot_common_dot_v1_dot_common__v1__pb2
from nds.event.v1 import event_v1_pb2 as nds_dot_event_dot_v1_dot_event__v1__pb2
from nds.identity.v1 import identity_v1_pb2 as nds_dot_identity_dot_v1_dot_identity__v1__pb2
from nds.ledger.v1 import ledger_pb2 as nds_dot_ledger_dot_v1_dot_ledger__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16nds/sync/v1/sync.proto\x12\x0bnds.sync.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dnds/common/v1/common_v1.proto\x1a\x1bnds/event/v1/event_v1.proto\x1a!nds/identity/v1/identity_v1.proto\x1a\x1ands/ledger/v1/ledger.proto\"#\n\x0bResumeToken\x12\x14\n\x05value\x18\x01 \x01(\x0cR\x05value\"\xa9\x03\n\x16SubscribeEventsRequest\x12\x35\n\x06resume\x18\x01 \x01(\x0b\x32\x18.nds.sync.v1.ResumeTokenH\x00R\x06resume\x88\x01\x01\x12\x35\n\x05since\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\x05since\x88\x01\x01\x12-\n\x05types\x18\x03 \x03(\x0e\x32\x17.nds.event.v1.EventTypeR\x05types\x12\x35\n\x05owner\x18\x04 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdH\x02R\x05owner\x88\x01\x01\x12\x31\n\x15max_events_per_second\x18\n \x01(\x05R\x12maxEventsPerSecond\x12\'\n\rmax_in_flight\x18\x0b \x01(\x05H\x03R\x0bmaxInFlight\x88\x01\x01\x12 \n\tpage_size\x18\x0c \x01(\x05H\x04R\x08pageSize\x88\x01\x01\x42\t\n\x07_resumeB\x08\n\x06_sinceB\x08\n\x06_ownerB\x10\n\x0e_max_in_flightB\x0c\n\n_page_size\"\xd0\x02\n\x17SubscribeEventsResponse\x12\x35\n\x06resume\x18\x01 \x01(\x0b\x32\x18.nds.sync.v1.ResumeTokenH\x01R\x06resume\x88\x01\x01\x12:\n\x08ordering\x18\x02 \x01(\x0e\x32\x19.nds.sync.v1.OrderingModeH\x02R\x08ordering\x88\x01\x01\x12\x33\n\x05\x65vent\x18\n \x01(\x0b\x32\x1b.nds.event.v1.EventEnvelopeH\x00R\x05\x65vent\x12\x36\n\theartbeat\x18\x0b \x01(\x0b\x32\x16.nds.sync.v1.HeartbeatH\x00R\theartbeat\x12\x32\n\x05\x65rror\x18\x0c \x01(\x0b\x32\x1a.nds.common.v1.ErrorStatusH\x00R\x05\x65rrorB\t\n\x07messageB\t\n\x07_resumeB\x0b\n\t_ordering\"C\n\tHeartbeat\x12/\n\x02\x61t\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x02\x61t\x88\x01\x01\x42\x05\n\x03_at\"\xf4\x01\n\x13WatchBalanceRequest\x12+\n\x03key\x18\x01 \x01(\x0b\x32\x19.nds.ledger.v1.BalanceKeyR\x03key\x12\x35\n\x06resume\x18\x02 \x01(\x0b\x32\x18.nds.sync.v1.ResumeTokenH\x00R\x06resume\x88\x01\x01\x12\x33\n\x16max_updates_per_second\x18\n \x01(\x05R\x13maxUpdatesPerSecond\x12\'\n\rmax_in_flight\x18\x0b \x01(\x05H\x01R\x0bmaxInFlight\x88\x01\x01\x42\t\n\x07_resumeB\x10\n\x0e_max_in_flight\"q\n\x0f\x42\x61lanceSnapshot\x12\x30\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x16.nds.ledger.v1.BalanceR\x07\x62\x61lance\x12,\n\x06\x63ursor\x18\x02 \x01(\x0b\x32\x14.nds.event.v1.CursorR\x06\x63ursor\"\x94\x02\n\x0c\x42\x61lanceDelta\x12+\n\x03key\x18\x01 \x01(\x0b\x32\x19.nds.ledger.v1.BalanceKeyR\x03key\x12*\n\x05\x64\x65lta\x18\x02 \x01(\x0b\x32\x14.nds.ledger.v1.MoneyR\x05\x64\x65lta\x12\x1f\n\x0bnew_version\x18\x03 \x01(\x04R\nnewVersion\x12,\n\x06\x63ursor\x18\x04 \x01(\x0b\x32\x14.nds.event.v1.CursorR\x06\x63ursor\x12\x1e\n\x0bproof_tx_id\x18\x05 \x01(\x0cR\tproofTxId\x12)\n\x0eproof_event_id\x18\x06 \x01(\x0cH\x00R\x0cproofEventId\x88\x01\x01\x42\x11\n\x0f_proof_event_id\"\x87\x03\n\x14WatchBalanceResponse\x12\x35\n\x06resume\x18\x01 \x01(\x0b\x32\x18.nds.sync.v1.ResumeTokenH\x01R\x06resume\x88\x01\x01\x12:\n\x08ordering\x18\x02 \x01(\x0e\x32\x19.nds.sync.v1.OrderingModeH\x02R\x08ordering\x88\x01\x01\x12:\n\x08snapshot\x18\n \x01(\x0b\x32\x1c.nds.sync.v1.BalanceSnapshotH\x00R\x08snapshot\x12\x31\n\x05\x64\x65lta\x18\x0b \x01(\x0b\x32\x19.nds.sync.v1.BalanceDeltaH\x00R\x05\x64\x65lta\x12\x32\n\x05\x65rror\x18\x0c \x01(\x0b\x32\x1a.nds.common.v1.ErrorStatusH\x00R\x05\x65rror\x12\x36\n\theartbeat\x18\r \x01(\x0b\x32\x16.nds.sync.v1.HeartbeatH\x00R\theartbeatB\t\n\x07messageB\t\n\x07_resumeB\x0b\n\t_ordering*e\n\x0cOrderingMode\x12\x1d\n\x19ORDERING_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13ORDERING_MODE_TOTAL\x10\x01\x12\x1d\n\x19ORDERING_MODE_PARTITIONED\x10\x02\x42\xc5\x01\n6noie.linmimeng.noiedigitalsystem.api.proto.nds.sync.v1B\tSyncProtoP\x01Z2github.com/misty4119/nds-api/Go/nds/sync/v1;syncv1\xa2\x02\x03NSX\xaa\x02\x0bNds.Sync.V1\xca\x02\x0bNds\\Sync\\V1\xe2\x02\x17Nds\\Sync\\V1\\GPBMetadata\xea\x02\rNds::Sync::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.sync.v1.sync_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n6noie.linmimeng.noiedigitalsystem.api.proto.nds.sync.v1B\tSyncProtoP\001Z2github.com/misty4119/nds-api/Go/nds/sync/v1;syncv1\242\002\003NSX\252\002\013Nds.Sync.V1\312\002\013Nds\\Sync\\V1\342\002\027Nds\\Sync\\V1\\GPBMetadata\352\002\rNds::Sync::V1'
  _globals['_ORDERINGMODE']._serialized_start=2103
  _globals['_ORDERINGMODE']._serialized_end=2204
  _globals['_RESUMETOKEN']._serialized_start=195
  _globals['_RESUMETOKEN']._serialized_end=230
  _globals['_SUBSCRIBEEVENTSREQUEST']._serialized_start=233
  _globals['_SUBSCRIBEEVENTSREQUEST']._serialized_end=658
  _globals['_SUBSCRIBEEVENTSRESPONSE']._serialized_start=661
  _globals['_SUBSCRIBEEVENTSRESPONSE']._serialized_end=997
  _globals['_HEARTBEAT']._serialized_start=999
  _globals['_HEARTBEAT']._serialized_end=1066
  _globals['_WATCHBALANCEREQUEST']._serialized_start=1069
  _globals['_WATCHBALANCEREQUEST']._serialized_end=1313
  _globals['_BALANCESNAPSHOT']._serialized_start=1315
  _globals['_BALANCESNAPSHOT']._serialized_end=1428
  _globals['_BALANCEDELTA']._serialized_start=1431
  _globals['_BALANCEDELTA']._serialized_end=1707
  _globals['_WATCHBALANCERESPONSE']._serialized_start=1710
  _globals['_WATCHBALANCERESPONSE']._serialized_end=2101
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/asset/asset.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/asset/asset.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nds.common import common_pb2 as nds_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15nds/asset/asset.proto\x12\tnds.asset\x1a\x17nds/common/common.proto\"J\n\x07\x41ssetId\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12+\n\x05scope\x18\x02 \x01(\x0e\x32\x15.nds.asset.AssetScopeR\x05scope\"\x99\x03\n\x08NdsAsset\x12-\n\x08\x61sset_id\x18\x01 \x01(\x0b\x32\x12.nds.asset.AssetIdR\x07\x61ssetId\x12\x31\n\x04tags\x18\x02 \x03(\x0b\x32\x1d.nds.asset.NdsAsset.TagsEntryR\x04tags\x12=\n\x08metadata\x18\x03 \x03(\x0b\x32!.nds.asset.NdsAsset.MetadataEntryR\x08metadata\x12.\n\x05limit\x18\x04 \x01(\x0b\x32\x13.nds.common.DecimalH\x00R\x05limit\x88\x01\x01\x12\x1d\n\ncreated_at\x18\x05 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x06 \x01(\x03R\tupdatedAt\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_limit*q\n\nAssetScope\x12\x1b\n\x17\x41SSET_SCOPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x41SSET_SCOPE_PLAYER\x10\x01\x12\x16\n\x12\x41SSET_SCOPE_SERVER\x10\x02\x12\x16\n\x12\x41SSET_SCOPE_GLOBAL\x10\x03\x42\xb2\x01\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.assetB\nAssetProtoP\x01Z)github.com/misty4119/nds-api/Go/nds/asset\xa2\x02\x03NAX\xaa\x02\tNds.Asset\xca\x02\tNds\\Asset\xe2\x02\x15Nds\\Asset\\GPBMetadata\xea\x02\nNds::Assetb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.asset.asset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.assetB\nAssetProtoP\001Z)github.com/misty4119/nds-api/Go/nds/asset\242\002\003NAX\252\002\tNds.Asset\312\002\tNds\\Asset\342\002\025Nds\\Asset\\GPBMetadata\352\002\nNds::Asset'
  _globals['_NDSASSET_TAGSENTRY']._loaded_options = None
  _globals['_NDSASSET_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_NDSASSET_METADATAENTRY']._loaded_options = None
  _globals['_NDSASSET_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ASSETSCOPE']._serialized_start=549
  _globals['_ASSETSCOPE']._serialized_end=662
  _globals['_ASSETID']._serialized_start=61
  _globals['_ASSETID']._serialized_end=135
  _globals['_NDSASSET']._serialized_start=138
  _globals['_NDSASSET']._serialized_end=547
  _globals['_NDSASSET_TAGSENTRY']._serialized_start=421
  _globals['_NDSASSET_TAGSENTRY']._serialized_end=476
  _globals['_NDSASSET_METADATAENTRY']._serialized_start=478
  _globals['_NDSASSET_METADATAENTRY']._serialized_end=537
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/ledger/v1/ledger.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/ledger/v1/ledger.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from nds.common.v1 import common_v1_pb2 as nds_dot_common_dot_v1_dot_common__v1__pb2
from nds.event.v1 import event_v1_pb2 as nds_dot_event_dot_v1_dot_event__v1__pb2
from nds.identity.v1 import identity_v1_pb2 as nds_dot_identity_dot_v1_dot_identity__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ands/ledger/v1/ledger.proto\x12\rnds.ledger.v1\x1a\x19google/protobuf/any.proto\x1a\x1dnds/common/v1/common_v1.proto\x1a\x1bnds/event/v1/event_v1.proto\x1a!nds/identity/v1/identity_v1.proto\"X\n\x05Money\x12#\n\rcurrency_code\x18\x01 \x01(\tR\x0c\x63urrencyCode\x12\x14\n\x05units\x18\x02 \x01(\x03R\x05units\x12\x14\n\x05nanos\x18\x03 \x01(\x05R\x05nanos\"c\n\nBalanceKey\x12\x30\n\x05owner\x18\x01 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdR\x05owner\x12#\n\rcurrency_code\x18\x02 \x01(\tR\x0c\x63urrencyCode\"~\n\x07\x42\x61lance\x12+\n\x03key\x18\x01 \x01(\x0b\x32\x19.nds.ledger.v1.BalanceKeyR\x03key\x12,\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x14.nds.ledger.v1.MoneyR\x06\x61mount\x12\x18\n\x07version\x18\x03 \x01(\x04R\x07version\"\xc3\x04\n\x18\x43reateTransactionRequest\x12\x30\n\x05\x61\x63tor\x18\x01 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdR\x05\x61\x63tor\x12\x37\n\x06source\x18\x02 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdH\x00R\x06source\x88\x01\x01\x12\x37\n\x06target\x18\x03 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdH\x01R\x06target\x88\x01\x01\x12,\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x14.nds.ledger.v1.MoneyR\x06\x61mount\x12/\n\x03\x63tx\x18\n \x01(\x0b\x32\x1d.nds.common.v1.RequestContextR\x03\x63tx\x12;\n\x17\x65xpected_source_version\x18\x0b \x01(\x04H\x02R\x15\x65xpectedSourceVersion\x88\x01\x01\x12;\n\x17\x65xpected_target_version\x18\x0c \x01(\x04H\x03R\x15\x65xpectedTargetVersion\x88\x01\x01\x12\x1b\n\x06reason\x18\x14 \x01(\tH\x04R\x06reason\x88\x01\x01\x12\x34\n\nextensions\x18\x1e \x03(\x0b\x32\x14.google.protobuf.AnyR\nextensionsB\t\n\x07_sourceB\t\n\x07_targetB\x1a\n\x18_expected_source_versionB\x1a\n\x18_expected_target_versionB\t\n\x07_reason\"\xc2\x01\n\x19\x43reateTransactionResponse\x12\x18\n\x05tx_id\x18\x01 \x01(\x0cH\x00R\x04txId\x88\x01\x01\x12\x36\n\x05\x65vent\x18\x02 \x01(\x0b\x32\x1b.nds.event.v1.EventEnvelopeH\x01R\x05\x65vent\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x1a.nds.common.v1.ErrorStatusH\x02R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_tx_idB\x08\n\x06_eventB\x08\n\x06_errorB\xd5\x01\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.ledger.v1B\x0bLedgerProtoP\x01Z6github.com/misty4119/nds-api/Go/nds/ledger/v1;ledgerv1\xa2\x02\x03NLX\xaa\x02\rNds.Ledger.V1\xca\x02\rNds\\Ledger\\V1\xe2\x02\x19Nds\\Ledger\\V1\\GPBMetadata\xea\x02\x0fNds::Ledger::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.ledger.v1.ledger_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.ledger.v1B\013LedgerProtoP\001Z6github.com/misty4119/nds-api/Go/nds/ledger/v1;ledgerv1\242\002\003NLX\252\002\rNds.Ledger.V1\312\002\rNds\\Ledger\\V1\342\002\031Nds\\Ledger\\V1\\GPBMetadata\352\002\017Nds::Ledger::V1'
  _globals['_MONEY']._serialized_start=167
  _globals['_MONEY']._serialized_end=255
  _globals['_BALANCEKEY']._serialized_start=257
  _globals['_BALANCEKEY']._serialized_end=356
  _globals['_BALANCE']._serialized_start=358
  _globals['_BALANCE']._serialized_end=484
  _globals['_CREATETRANSACTIONREQUEST']._serialized_start=487
  _globals['_CREATETRANSACTIONREQUEST']._serialized_end=1066
  _globals['_CREATETRANSACTIONRESPONSE']._serialized_start=1069
  _globals['_CREATETRANSACTIONRESPONSE']._serialized_end=1263
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/query/query.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/query/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nds.common import common_pb2 as nds_dot_common_dot_common__pb2
from nds.identity import identity_pb2 as nds_dot_identity_dot_identity__pb2
from nds.asset import asset_pb2 as nds_dot_asset_dot_asset__pb2
from nds.event import event_pb2 as nds_dot_event_dot_event__pb2
from nds.context import context_pb2 as nds_dot_context_dot_context__pb2
from nds.projection import projection_pb2 as nds_dot_projection_dot_projection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15nds/query/query.proto\x12\tnds.query\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17nds/common/common.proto\x1a\x1bnds/identity/identity.proto\x1a\x15nds/asset/asset.proto\x1a\x15nds/event/event.proto\x1a\x19nds/context/context.proto\x1a\x1fnds/projection/projection.proto\"\xcc\x01\n\x13QueryBalanceRequest\x12(\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x12.nds.asset.AssetIdR\x05\x61sset\x12:\n\x08identity\x18\x02 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x00R\x08identity\x88\x01\x01\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32\x17.nds.context.NdsContextH\x01R\x07\x63ontext\x88\x01\x01\x42\x0b\n\t_identityB\n\n\x08_context\"\x85\x01\n\x14QueryBalanceResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12\x32\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x13.nds.common.DecimalH\x00R\x07\x62\x61lance\x88\x01\x01\x42\n\n\x08_balance\"\xa1\x03\n\x13QueryHistoryRequest\x12-\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x12.nds.asset.AssetIdH\x00R\x05\x61sset\x88\x01\x01\x12:\n\x08identity\x18\x02 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x01R\x08identity\x88\x01\x01\x12>\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\tstartTime\x88\x01\x01\x12:\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x03R\x07\x65ndTime\x88\x01\x01\x12\x14\n\x05limit\x18\x05 \x01(\x05R\x05limit\x12\x16\n\x06offset\x18\x06 \x01(\x05R\x06offset\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32\x17.nds.context.NdsContextH\x04R\x07\x63ontext\x88\x01\x01\x42\x08\n\x06_assetB\x0b\n\t_identityB\r\n\x0b_start_timeB\x0b\n\t_end_timeB\n\n\x08_context\"\x93\x01\n\x14QueryHistoryResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12+\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x13.nds.event.NdsEventR\x06\x65vents\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x03R\ntotalCount\"\x9f\x01\n\x16QueryProjectionRequest\x12\x41\n\rprojection_id\x18\x01 \x01(\x0b\x32\x1c.nds.projection.ProjectionIdR\x0cprojectionId\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x42\n\n\x08_context\"\x9b\x01\n\x17QueryProjectionResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12\x42\n\nprojection\x18\x02 \x01(\x0b\x32\x1d.nds.projection.NdsProjectionH\x00R\nprojection\x88\x01\x01\x42\r\n\x0b_projection\"\xd3\x01\n\rReplayRequest\x12\x41\n\rprojection_id\x18\x01 \x01(\x0b\x32\x1c.nds.projection.ProjectionIdR\x0cprojectionId\x12;\n\x0btarget_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ntargetTime\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x42\n\n\x08_context\"\x92\x01\n\x0eReplayResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12\x42\n\nprojection\x18\x02 \x01(\x0b\x32\x1d.nds.projection.NdsProjectionH\x00R\nprojection\x88\x01\x01\x42\r\n\x0b_projection\"\xba\x01\n\x19RegisterProjectionRequest\x12\x41\n\rprojection_id\x18\x01 \x01(\x0b\x32\x1c.nds.projection.ProjectionIdR\x0cprojectionId\x12\x16\n\x06\x63onfig\x18\x02 \x01(\tR\x06\x63onfig\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x42\n\n\x08_context\"K\n\x1aRegisterProjectionResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\"\xa4\x01\n\x1bUnregisterProjectionRequest\x12\x41\n\rprojection_id\x18\x01 \x01(\x0b\x32\x1c.nds.projection.ProjectionIdR\x0cprojectionId\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x42\n\n\x08_context\"M\n\x1cUnregisterProjectionResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result2\x98\x04\n\x0fNdsQueryService\x12O\n\x0cQueryBalance\x12\x1e.nds.query.QueryBalanceRequest\x1a\x1f.nds.query.QueryBalanceResponse\x12O\n\x0cQueryHistory\x12\x1e.nds.query.QueryHistoryRequest\x1a\x1f.nds.query.QueryHistoryResponse\x12X\n\x0fQueryProjection\x12!.nds.query.QueryProjectionRequest\x1a\".nds.query.QueryProjectionResponse\x12=\n\x06Replay\x12\x18.nds.query.ReplayRequest\x1a\x19.nds.query.ReplayResponse\x12\x61\n\x12RegisterProjection\x12$.nds.query.RegisterProjectionRequest\x1a%.nds.query.RegisterProjectionResponse\x12g\n\x14UnregisterProjection\x12&.nds.query.UnregisterProjectionRequest\x1a\'.nds.query.UnregisterProjectionResponseB\xb2\x01\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.queryB\nQueryProtoP\x01Z)github.com/misty4119/nds-api/Go/nds/query\xa2\x02\x03NQX\xaa\x02\tNds.Query\xca\x02\tNds\\Query\xe2\x02\x15Nds\\Query\\GPBMetadata\xea\x02\nNds::Queryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.query.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.queryB\nQueryProtoP\001Z)github.com/misty4119/nds-api/Go/nds/query\242\002\003NQX\252\002\tNds.Query\312\002\tNds\\Query\342\002\025Nds\\Query\\GPBMetadata\352\002\nNds::Query'
  _globals['_QUERYBALANCEREQUEST']._serialized_start=230
  _globals['_QUERYBALANCEREQUEST']._serialized_end=434
  _globals['_QUERYBALANCERESPONSE']._serialized_start=437
  _globals['_QUERYBALANCERESPONSE']._serialized_end=570
  _globals['_QUERYHISTORYREQUEST']._serialized_start=573
  _globals['_QUERYHISTORYREQUEST']._serialized_end=990
  _globals['_QUERYHISTORYRESPONSE']._serialized_start=993
  _globals['_QUERYHISTORYRESPONSE']._serialized_end=1140
  _globals['_QUERYPROJECTIONREQUEST']._serialized_start=1143
  _globals['_QUERYPROJECTIONREQUEST']._serialized_end=1302
  _globals['_QUERYPROJECTIONRESPONSE']._serialized_start=1305
  _globals['_QUERYPROJECTIONRESPONSE']._serialized_end=1460
  _globals['_REPLAYREQUEST']._serialized_start=1463
  _globals['_REPLAYREQUEST']._serialized_end=1674
  _globals['_REPLAYRESPONSE']._serialized_start=1677
  _globals['_REPLAYRESPONSE']._serialized_end=1823
  _globals['_REGISTERPROJECTIONREQUEST']._serialized_start=1826
  _globals['_REGISTERPROJECTIONREQUEST']._serialized_end=2012
  _globals['_REGISTERPROJECTIONRESPONSE']._serialized_start=2014
  _globals['_REGISTERPROJECTIONRESPONSE']._serialized_end=2089
  _globals['_UNREGISTERPROJECTIONREQUEST']._serialized_start=2092
  _globals['_UNREGISTERPROJECTIONREQUEST']._serialized_end=2256
  _globals['_UNREGISTERPROJECTIONRESPONSE']._serialized_start=2258
  _globals['_UNREGISTERPROJECTIONRESPONSE']._serialized_end=2335
  _globals['_NDSQUERYSERVICE']._serialized_start=2338
  _globals['_NDSQUERYSERVICE']._serialized_end=2874
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/identity/identity.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/identity/identity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bnds/identity/identity.proto\x12\x0cnds.identity\"\xff\x01\n\x0bNdsIdentity\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12.\n\x04type\x18\x02 \x01(\x0e\x32\x1a.nds.identity.IdentityTypeR\x04type\x12\x43\n\x08metadata\x18\x03 \x03(\x0b\x32\'.nds.identity.NdsIdentity.MetadataEntryR\x08metadata\x12.\n\x13\x61ttached_policy_ids\x18\n \x03(\tR\x11\x61ttachedPolicyIds\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\x93\x01\n\x0cIdentityType\x12\x1d\n\x19IDENTITY_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14IDENTITY_TYPE_PLAYER\x10\x01\x12\x18\n\x14IDENTITY_TYPE_SYSTEM\x10\x02\x12\x14\n\x10IDENTITY_TYPE_AI\x10\x03\x12\x1a\n\x16IDENTITY_TYPE_EXTERNAL\x10\x04\x42\xc7\x01\n7noie.linmimeng.noiedigitalsystem.api.proto.nds.identityB\rIdentityProtoP\x01Z,github.com/misty4119/nds-api/Go/nds/identity\xa2\x02\x03NIX\xaa\x02\x0cNds.Identity\xca\x02\x0cNds\\Identity\xe2\x02\x18Nds\\Identity\\GPBMetadata\xea\x02\rNds::Identityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.identity.identity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7noie.linmimeng.noiedigitalsystem.api.proto.nds.identityB\rIdentityProtoP\001Z,github.com/misty4119/nds-api/Go/nds/identity\242\002\003NIX\252\002\014Nds.Identity\312\002\014Nds\\Identity\342\002\030Nds\\Identity\\GPBMetadata\352\002\rNds::Identity'
  _globals['_NDSIDENTITY_METADATAENTRY']._loaded_options = None
  _globals['_NDSIDENTITY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_IDENTITYTYPE']._serialized_start=304
  _globals['_IDENTITYTYPE']._serialized_end=451
  _globals['_NDSIDENTITY']._serialized_start=46
  _globals['_NDSIDENTITY']._serialized_end=301
  _globals['_NDSIDENTITY_METADATAENTRY']._serialized_start=242
  _globals['_NDSIDENTITY_METADATAENTRY']._serialized_end=301
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/projection/projection.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/projection/projection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fnds/projection/projection.proto\x12\x0ends.projection\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"<\n\x0cProjectionId\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07version\x18\x02 \x01(\x05R\x07version\"\x8a\x03\n\rNdsProjection\x12,\n\x02id\x18\x01 \x01(\x0b\x32\x1c.nds.projection.ProjectionIdR\x02id\x12\x38\n\x06status\x18\x02 \x01(\x0e\x32 .nds.projection.ProjectionStatusR\x06status\x12\"\n\rlast_event_id\x18\x03 \x01(\tR\x0blastEventId\x12=\n\x0clast_updated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0blastUpdated\x12(\n\x04\x64\x61ta\x18\x05 \x01(\x0b\x32\x14.google.protobuf.AnyR\x04\x64\x61ta\x12G\n\x08metadata\x18\x06 \x03(\x0b\x32+.nds.projection.NdsProjection.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xa2\x01\n\x11\x42\x61lanceProjection\x12\x18\n\x07\x62\x61lance\x18\x01 \x01(\tR\x07\x62\x61lance\x12\x19\n\x08\x61sset_id\x18\x02 \x01(\tR\x07\x61ssetId\x12\x19\n\x08owner_id\x18\x03 \x01(\tR\x07ownerId\x12=\n\x0clast_updated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0blastUpdated\"\xe6\x01\n\x10LeaderboardEntry\x12\x12\n\x04rank\x18\x01 \x01(\x05R\x04rank\x12\x1f\n\x0bidentity_id\x18\x02 \x01(\tR\nidentityId\x12\x14\n\x05value\x18\x03 \x01(\tR\x05value\x12J\n\x08metadata\x18\x04 \x03(\x0b\x32..nds.projection.LeaderboardEntry.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc1\x01\n\x15LeaderboardProjection\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x19\n\x08\x61sset_id\x18\x02 \x01(\tR\x07\x61ssetId\x12:\n\x07\x65ntries\x18\x03 \x03(\x0b\x32 .nds.projection.LeaderboardEntryR\x07\x65ntries\x12=\n\x0clast_updated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0blastUpdated*\xb2\x01\n\x10ProjectionStatus\x12!\n\x1dPROJECTION_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18PROJECTION_STATUS_ACTIVE\x10\x01\x12 \n\x1cPROJECTION_STATUS_REBUILDING\x10\x02\x12\x1e\n\x1aPROJECTION_STATUS_DISABLED\x10\x03\x12\x1b\n\x17PROJECTION_STATUS_ERROR\x10\x04\x42\xd5\x01\n9noie.linmimeng.noiedigitalsystem.api.proto.nds.projectionB\x0fProjectionProtoP\x01Z.github.com/misty4119/nds-api/Go/nds/projection\xa2\x02\x03NPX\xaa\x02\x0eNds.Projection\xca\x02\x0eNds\\Projection\xe2\x02\x1aNds\\Projection\\GPBMetadata\xea\x02\x0fNds::Projectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.projection.projection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n9noie.linmimeng.noiedigitalsystem.api.proto.nds.projectionB\017ProjectionProtoP\001Z.github.com/misty4119/nds-api/Go/nds/projection\242\002\003NPX\252\002\016Nds.Projection\312\002\016Nds\\Projection\342\002\032Nds\\Projection\\GPBMetadata\352\002\017Nds::Projection'
  _globals['_NDSPROJECTION_METADATAENTRY']._loaded_options = None
  _globals['_NDSPROJECTION_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_LEADERBOARDENTRY_METADATAENTRY']._loaded_options = None
  _globals['_LEADERBOARDENTRY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_PROJECTIONSTATUS']._serialized_start=1165
  _globals['_PROJECTIONSTATUS']._serialized_end=1343
  _globals['_PROJECTIONID']._serialized_start=111
  _globals['_PROJECTIONID']._serialized_end=171
  _globals['_NDSPROJECTION']._serialized_start=174
  _globals['_NDSPROJECTION']._serialized_end=568
  _globals['_NDSPROJECTION_METADATAENTRY']._serialized_start=509
  _globals['_NDSPROJECTION_METADATAENTRY']._serialized_end=568
  _globals['_BALANCEPROJECTION']._serialized_start=571
  _globals['_BALANCEPROJECTION']._serialized_end=733
  _globals['_LEADERBOARDENTRY']._serialized_start=736
  _globals['_LEADERBOARDENTRY']._serialized_end=966
  _globals['_LEADERBOARDENTRY_METADATAENTRY']._serialized_start=509
  _globals['_LEADERBOARDENTRY_METADATAENTRY']._serialized_end=568
  _globals['_LEADERBOARDPROJECTION']._serialized_start=969
  _globals['_LEADERBOARDPROJECTION']._serialized_end=1162
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/transaction/transaction.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/transaction/transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nds.common import common_pb2 as nds_dot_common_dot_common__pb2
from nds.identity import identity_pb2 as nds_dot_identity_dot_identity__pb2
from nds.asset import asset_pb2 as nds_dot_asset_dot_asset__pb2
from nds.event import event_pb2 as nds_dot_event_dot_event__pb2
from nds.context import context_pb2 as nds_dot_context_dot_context__pb2
from nds.audit import rationale_pb2 as nds_dot_audit_dot_rationale__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nds/transaction/transaction.proto\x12\x0fnds.transaction\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17nds/common/common.proto\x1a\x1bnds/identity/identity.proto\x1a\x15nds/asset/asset.proto\x1a\x15nds/event/event.proto\x1a\x19nds/context/context.proto\x1a\x19nds/audit/rationale.proto\"\xbe\x08\n\x0eNdsTransaction\x12\"\n\x02id\x18\x01 \x01(\x0b\x32\x12.nds.event.EventIdR\x02id\x12;\n\x0boccurred_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12/\n\x05\x61\x63tor\x18\x03 \x01(\x0b\x32\x19.nds.identity.NdsIdentityR\x05\x61\x63tor\x12/\n\x07payload\x18\x04 \x01(\x0b\x32\x15.nds.event.NdsPayloadR\x07payload\x12%\n\x0eschema_version\x18\x05 \x01(\x05R\rschemaVersion\x12I\n\x08metadata\x18\x06 \x03(\x0b\x32-.nds.transaction.NdsTransaction.MetadataEntryR\x08metadata\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x12(\n\x05\x61sset\x18\n \x01(\x0b\x32\x12.nds.asset.AssetIdR\x05\x61sset\x12)\n\x05\x64\x65lta\x18\x0b \x01(\x0b\x32\x13.nds.common.DecimalR\x05\x64\x65lta\x12\x42\n\x0b\x63onsistency\x18\x0c \x01(\x0e\x32 .nds.transaction.ConsistencyModeR\x0b\x63onsistency\x12\x36\n\x06source\x18\r \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x01R\x06source\x88\x01\x01\x12\x36\n\x06target\x18\x0e \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x02R\x06target\x88\x01\x01\x12\x1b\n\x06reason\x18\x0f \x01(\tH\x03R\x06reason\x88\x01\x01\x12:\n\x06status\x18\x10 \x01(\x0e\x32\".nds.transaction.TransactionStatusR\x06status\x12\x37\n\x15\x65nforcement_policy_id\x18\x11 \x01(\tH\x04R\x13\x65nforcementPolicyId\x88\x01\x01\x12:\n\trationale\x18\x12 \x01(\x0b\x32\x17.nds.audit.NdsRationaleH\x05R\trationale\x88\x01\x01\x12\x44\n\rrationale_ref\x18\x13 \x01(\x0b\x32\x1a.nds.audit.NdsRationaleRefH\x06R\x0crationaleRef\x88\x01\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\n\n\x08_contextB\t\n\x07_sourceB\t\n\x07_targetB\t\n\x07_reasonB\x18\n\x16_enforcement_policy_idB\x0c\n\n_rationaleB\x10\n\x0e_rationale_ref\"\xe8\x04\n\x18\x43reateTransactionRequest\x12(\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x12.nds.asset.AssetIdR\x05\x61sset\x12)\n\x05\x64\x65lta\x18\x02 \x01(\x0b\x32\x13.nds.common.DecimalR\x05\x64\x65lta\x12/\n\x05\x61\x63tor\x18\x03 \x01(\x0b\x32\x19.nds.identity.NdsIdentityR\x05\x61\x63tor\x12\x42\n\x0b\x63onsistency\x18\x04 \x01(\x0e\x32 .nds.transaction.ConsistencyModeR\x0b\x63onsistency\x12\x36\n\x06source\x18\x05 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x00R\x06source\x88\x01\x01\x12\x36\n\x06target\x18\x06 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x01R\x06target\x88\x01\x01\x12\x1b\n\x06reason\x18\x07 \x01(\tH\x02R\x06reason\x88\x01\x01\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32\x17.nds.context.NdsContextH\x03R\x07\x63ontext\x88\x01\x01\x12S\n\x08metadata\x18\t \x03(\x0b\x32\x37.nds.transaction.CreateTransactionRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\t\n\x07_sourceB\t\n\x07_targetB\t\n\x07_reasonB\n\n\x08_context\"\xa2\x01\n\x19\x43reateTransactionResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12\x46\n\x0btransaction\x18\x02 \x01(\x0b\x32\x1f.nds.transaction.NdsTransactionH\x00R\x0btransaction\x88\x01\x01\x42\x0e\n\x0c_transaction\"K\n\x1aPreviewTransactionResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\"\xac\x02\n\x1e\x42\x61tchCreateTransactionsRequest\x12\x45\n\x08requests\x18\x01 \x03(\x0b\x32).nds.transaction.CreateTransactionRequestR\x08requests\x12\x1e\n\x08\x62\x61tch_id\x18\x02 \x01(\tH\x00R\x07\x62\x61tchId\x88\x01\x01\x12Y\n\x08metadata\x18\x03 \x03(\x0b\x32=.nds.transaction.BatchCreateTransactionsRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0b\n\t_batch_id\"\x9a\x01\n\x1f\x42\x61tchCreateTransactionsResponse\x12-\n\x06result\x18\x01 \x01(\x0b\x32\x15.nds.common.NdsResultR\x06result\x12H\n\tresponses\x18\x02 \x03(\x0b\x32*.nds.transaction.CreateTransactionResponseR\tresponses\"\xae\x04\n\x19StreamTransactionsRequest\x12-\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x12.nds.asset.AssetIdH\x00R\x05\x61sset\x88\x01\x01\x12\x34\n\x05\x61\x63tor\x18\x02 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x01R\x05\x61\x63tor\x88\x01\x01\x12\x36\n\x06source\x18\x03 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x02R\x06source\x88\x01\x01\x12\x36\n\x06target\x18\x04 \x01(\x0b\x32\x19.nds.identity.NdsIdentityH\x03R\x06target\x88\x01\x01\x12\x35\n\x05since\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x04R\x05since\x88\x01\x01\x12>\n\x08statuses\x18\x06 \x03(\x0e\x32\".nds.transaction.TransactionStatusR\x08statuses\x12T\n\x08metadata\x18\x07 \x03(\x0b\x32\x38.nds.transaction.StreamTransactionsRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_assetB\x08\n\x06_actorB\t\n\x07_sourceB\t\n\x07_targetB\x08\n\x06_since*\x90\x01\n\x0f\x43onsistencyMode\x12 \n\x1c\x43ONSISTENCY_MODE_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43ONSISTENCY_MODE_STRONG\x10\x01\x12\x1d\n\x19\x43ONSISTENCY_MODE_EVENTUAL\x10\x02\x12\x1f\n\x1b\x43ONSISTENCY_MODE_OPTIMISTIC\x10\x03*\xbc\x01\n\x11TransactionStatus\x12\"\n\x1eTRANSACTION_STATUS_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTRANSACTION_STATUS_PENDING\x10\x01\x12 \n\x1cTRANSACTION_STATUS_COMMITTED\x10\x02\x12\"\n\x1eTRANSACTION_STATUS_ROLLED_BACK\x10\x03\x12\x1d\n\x19TRANSACTION_STATUS_FAILED\x10\x04\x42\xdc\x01\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.transactionB\x10TransactionProtoP\x01Z/github.com/misty4119/nds-api/Go/nds/transaction\xa2\x02\x03NTX\xaa\x02\x0fNds.Transaction\xca\x02\x0fNds\\Transaction\xe2\x02\x1bNds\\Transaction\\GPBMetadata\xea\x02\x10Nds::Transactionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.transaction.transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.transactionB\020TransactionProtoP\001Z/github.com/misty4119/nds-api/Go/nds/transaction\242\002\003NTX\252\002\017Nds.Transaction\312\002\017Nds\\Transaction\342\002\033Nds\\Transaction\\GPBMetadata\352\002\020Nds::Transaction'
  _globals['_NDSTRANSACTION_METADATAENTRY']._loaded_options = None
  _globals['_NDSTRANSACTION_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATETRANSACTIONREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CREATETRANSACTIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_BATCHCREATETRANSACTIONSREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_BATCHCREATETRANSACTIONSREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_STREAMTRANSACTIONSREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_STREAMTRANSACTIONSREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CONSISTENCYMODE']._serialized_start=3213
  _globals['_CONSISTENCYMODE']._serialized_end=3357
  _globals['_TRANSACTIONSTATUS']._serialized_start=3360
  _globals['_TRANSACTIONSTATUS']._serialized_end=3548
  _globals['_NDSTRANSACTION']._serialized_start=242
  _globals['_NDSTRANSACTION']._serialized_end=1328
  _globals['_NDSTRANSACTION_METADATAENTRY']._serialized_start=1166
  _globals['_NDSTRANSACTION_METADATAENTRY']._serialized_end=1225
  _globals['_CREATETRANSACTIONREQUEST']._serialized_start=1331
  _globals['_CREATETRANSACTIONREQUEST']._serialized_end=1947
  _globals['_CREATETRANSACTIONREQUEST_METADATAENTRY']._serialized_start=1166
  _globals['_CREATETRANSACTIONREQUEST_METADATAENTRY']._serialized_end=1225
  _globals['_CREATETRANSACTIONRESPONSE']._serialized_start=1950
  _globals['_CREATETRANSACTIONRESPONSE']._serialized_end=2112
  _globals['_PREVIEWTRANSACTIONRESPONSE']._serialized_start=2114
  _globals['_PREVIEWTRANSACTIONRESPONSE']._serialized_end=2189
  _globals['_BATCHCREATETRANSACTIONSREQUEST']._serialized_start=2192
  _globals['_BATCHCREATETRANSACTIONSREQUEST']._serialized_end=2492
  _globals['_BATCHCREATETRANSACTIONSREQUEST_METADATAENTRY']._serialized_start=1166
  _globals['_BATCHCREATETRANSACTIONSREQUEST_METADATAENTRY']._serialized_end=1225
  _globals['_BATCHCREATETRANSACTIONSRESPONSE']._serialized_start=2495
  _globals['_BATCHCREATETRANSACTIONSRESPONSE']._serialized_end=2649
  _globals['_STREAMTRANSACTIONSREQUEST']._serialized_start=2652
  _globals['_STREAMTRANSACTIONSREQUEST']._serialized_end=3210
  _globals['_STREAMTRANSACTIONSREQUEST_METADATAENTRY']._serialized_start=1166
  _globals['_STREAMTRANSACTIONSREQUEST_METADATAENTRY']._serialized_end=1225
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/audit/rationale.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/audit/rationale.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nds.common import common_pb2 as nds_dot_common_dot_common__pb2
from nds.event import event_pb2 as nds_dot_event_dot_event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19nds/audit/rationale.proto\x12\tnds.audit\x1a\x17nds/common/common.proto\x1a\x15nds/event/event.proto\"\xdd\x03\n\x0cNdsRationale\x12\x16\n\x06source\x18\x01 \x01(\tR\x06source\x12\x38\n\nconfidence\x18\x02 \x01(\x0b\x32\x13.nds.common.DecimalH\x00R\nconfidence\x88\x01\x01\x12!\n\x0cthought_path\x18\x03 \x03(\tR\x0bthoughtPath\x12@\n\x12\x65vidence_event_ids\x18\x04 \x03(\x0b\x32\x12.nds.event.EventIdR\x10\x65videnceEventIds\x12?\n\revidence_refs\x18\x08 \x03(\x0b\x32\x1a.nds.audit.NdsRationaleRefR\x0c\x65videnceRefs\x12\x37\n\nrisk_score\x18\x05 \x01(\x0b\x32\x13.nds.common.DecimalH\x01R\triskScore\x88\x01\x01\x12\x41\n\x08metadata\x18\x06 \x03(\x0b\x32%.nds.audit.NdsRationale.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\r\n\x0b_confidenceB\r\n\x0b_risk_score\"u\n\x0fNdsRationaleRef\x12\x10\n\x03uri\x18\x01 \x01(\tR\x03uri\x12\x17\n\x04hash\x18\x02 \x01(\tH\x00R\x04hash\x88\x01\x01\x12 \n\tmime_type\x18\x03 \x01(\tH\x01R\x08mimeType\x88\x01\x01\x42\x07\n\x05_hashB\x0c\n\n_mime_typeB\xb6\x01\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.auditB\x0eRationaleProtoP\x01Z)github.com/misty4119/nds-api/Go/nds/audit\xa2\x02\x03NAX\xaa\x02\tNds.Audit\xca\x02\tNds\\Audit\xe2\x02\x15Nds\\Audit\\GPBMetadata\xea\x02\nNds::Auditb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.audit.rationale_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.auditB\016RationaleProtoP\001Z)github.com/misty4119/nds-api/Go/nds/audit\242\002\003NAX\252\002\tNds.Audit\312\002\tNds\\Audit\342\002\025Nds\\Audit\\GPBMetadata\352\002\nNds::Audit'
  _globals['_NDSRATIONALE_METADATAENTRY']._loaded_options = None
  _globals['_NDSRATIONALE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_NDSRATIONALE']._serialized_start=89
  _globals['_NDSRATIONALE']._serialized_end=566
  _globals['_NDSRATIONALE_METADATAENTRY']._serialized_start=477
  _globals['_NDSRATIONALE_METADATAENTRY']._serialized_end=536
  _globals['_NDSRATIONALEREF']._serialized_start=568
  _globals['_NDSRATIONALEREF']._serialized_end=685
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/event/v1/event_v1.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/event/v1/event_v1.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nds.common.v1 import common_v1_pb2 as nds_dot_common_dot_v1_dot_common__v1__pb2
from nds.identity.v1 import identity_v1_pb2 as nds_dot_identity_dot_v1_dot_identity__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bnds/event/v1/event_v1.proto\x12\x0cnds.event.v1\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dnds/common/v1/common_v1.proto\x1a!nds/identity/v1/identity_v1.proto\"\x1e\n\x06\x43ursor\x12\x14\n\x05value\x18\x01 \x01(\x0cR\x05value\"\xb3\x04\n\rEventEnvelope\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\x0cR\x07\x65ventId\x12,\n\x06\x63ursor\x18\x02 \x01(\x0b\x32\x14.nds.event.v1.CursorR\x06\x63ursor\x12;\n\x0boccurred_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12\x30\n\x05\x61\x63tor\x18\n \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdR\x05\x61\x63tor\x12\x35\n\x05owner\x18\x0b \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdH\x00R\x05owner\x88\x01\x01\x12+\n\x04type\x18\x14 \x01(\x0e\x32\x17.nds.event.v1.EventTypeR\x04type\x12%\n\x0eschema_version\x18\x15 \x01(\x05R\rschemaVersion\x12.\n\x07payload\x18\x1e \x01(\x0b\x32\x14.google.protobuf.AnyR\x07payload\x12\x34\n\nextensions\x18\x1f \x03(\x0b\x32\x14.google.protobuf.AnyR\nextensions\x12\x34\n\x03\x63tx\x18( \x01(\x0b\x32\x1d.nds.common.v1.RequestContextH\x01R\x03\x63tx\x88\x01\x01\x12\"\n\nrequest_id\x18) \x01(\tH\x02R\trequestId\x88\x01\x01\x42\x08\n\x06_ownerB\x06\n\x04_ctxB\r\n\x0b_request_id*\xba\x01\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\"\n\x1e\x45VENT_TYPE_LEDGER_TX_COMMITTED\x10\x01\x12%\n!EVENT_TYPE_LEDGER_BALANCE_CHANGED\x10\x02\x12\x1d\n\x19\x45VENT_TYPE_IDENTITY_BOUND\x10\n\x12\'\n#EVENT_TYPE_MEMORY_ARTIFACT_ANCHORED\x10\x14\x42\xcf\x01\n7noie.linmimeng.noiedigitalsystem.api.proto.nds.event.v1B\x0c\x45ventV1ProtoP\x01Z4github.com/misty4119/nds-api/Go/nds/event/v1;eventv1\xa2\x02\x03NEX\xaa\x02\x0cNds.Event.V1\xca\x02\x0cNds\\Event\\V1\xe2\x02\x18Nds\\Event\\V1\\GPBMetadata\xea\x02\x0eNds::Event::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.event.v1.event_v1_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7noie.linmimeng.noiedigitalsystem.api.proto.nds.event.v1B\014EventV1ProtoP\001Z4github.com/misty4119/nds-api/Go/nds/event/v1;eventv1\242\002\003NEX\252\002\014Nds.Event.V1\312\002\014Nds\\Event\\V1\342\002\030Nds\\Event\\V1\\GPBMetadata\352\002\016Nds::Event::V1'
  _globals['_EVENTTYPE']._serialized_start=770
  _globals['_EVENTTYPE']._serialized_end=956
  _globals['_CURSOR']._serialized_start=171
  _globals['_CURSOR']._serialized_end=201
  _globals['_EVENTENVELOPE']._serialized_start=204
  _globals['_EVENTENVELOPE']._serialized_end=767
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/metadata/v1/metadata.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/metadata/v1/metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ends/metadata/v1/metadata.proto\x12\x0fnds.metadata.v1\x1a\x19google/protobuf/any.proto\"\xae\x01\n\x0f\x44isplayMetadata\x12&\n\x0c\x64isplay_name\x18\x01 \x01(\tH\x00R\x0b\x64isplayName\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x1e\n\x08icon_uri\x18\x03 \x01(\tH\x02R\x07iconUri\x88\x01\x01\x42\x0f\n\r_display_nameB\x0e\n\x0c_descriptionB\x0b\n\t_icon_uri\"\xac\x01\n\x0eSourceMetadata\x12(\n\rsource_system\x18\x01 \x01(\tH\x00R\x0csourceSystem\x88\x01\x01\x12$\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\tH\x01R\ncampaignId\x88\x01\x01\x12\x1c\n\x07task_id\x18\x03 \x01(\tH\x02R\x06taskId\x88\x01\x01\x42\x10\n\x0e_source_systemB\x0e\n\x0c_campaign_idB\n\n\x08_task_id\"\xf9\x02\n\x0eMetadataBundle\x12?\n\x07\x64isplay\x18\x01 \x01(\x0b\x32 .nds.metadata.v1.DisplayMetadataH\x00R\x07\x64isplay\x88\x01\x01\x12<\n\x06source\x18\x02 \x01(\x0b\x32\x1f.nds.metadata.v1.SourceMetadataH\x01R\x06source\x88\x01\x01\x12\x34\n\nextensions\x18\n \x03(\x0b\x32\x14.google.protobuf.AnyR\nextensions\x12Y\n\x0elegacy_entries\x18\x63 \x03(\x0b\x32\x32.nds.metadata.v1.MetadataBundle.LegacyEntriesEntryR\rlegacyEntries\x1a@\n\x12LegacyEntriesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\n\n\x08_displayB\t\n\x07_sourceB\xe5\x01\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.metadata.v1B\rMetadataProtoP\x01Z:github.com/misty4119/nds-api/Go/nds/metadata/v1;metadatav1\xa2\x02\x03NMX\xaa\x02\x0fNds.Metadata.V1\xca\x02\x0fNds\\Metadata\\V1\xe2\x02\x1bNds\\Metadata\\V1\\GPBMetadata\xea\x02\x11Nds::Metadata::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.metadata.v1.metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.metadata.v1B\rMetadataProtoP\001Z:github.com/misty4119/nds-api/Go/nds/metadata/v1;metadatav1\242\002\003NMX\252\002\017Nds.Metadata.V1\312\002\017Nds\\Metadata\\V1\342\002\033Nds\\Metadata\\V1\\GPBMetadata\352\002\021Nds::Metadata::V1'
  _globals['_METADATABUNDLE_LEGACYENTRIESENTRY']._loaded_options = None
  _globals['_METADATABUNDLE_LEGACYENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_DISPLAYMETADATA']._serialized_start=79
  _globals['_DISPLAYMETADATA']._serialized_end=253
  _globals['_SOURCEMETADATA']._serialized_start=256
  _globals['_SOURCEMETADATA']._serialized_end=428
  _globals['_METADATABUNDLE']._serialized_start=431
  _globals['_METADATABUNDLE']._serialized_end=808
  _globals['_METADATABUNDLE_LEGACYENTRIESENTRY']._serialized_start=721
  _globals['_METADATABUNDLE_LEGACYENTRIESENTRY']._serialized_end=785
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/policy/policy.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/policy/policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17nds/policy/policy.proto\x12\nnds.policy\"\xe2\x02\n\tNdsPolicy\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\x12\x1f\n\x0bpolicy_type\x18\x02 \x01(\tR\npolicyType\x12\x39\n\x06params\x18\x03 \x03(\x0b\x32!.nds.policy.NdsPolicy.ParamsEntryR\x06params\x12#\n\rcustom_config\x18\x04 \x01(\x0cR\x0c\x63ustomConfig\x12?\n\x08metadata\x18\x05 \x03(\x0b\x32#.nds.policy.NdsPolicy.MetadataEntryR\x08metadata\x1a\x39\n\x0bParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xb9\x01\n5noie.linmimeng.noiedigitalsystem.api.proto.nds.policyB\x0bPolicyProtoP\x01Z*github.com/misty4119/nds-api/Go/nds/policy\xa2\x02\x03NPX\xaa\x02\nNds.Policy\xca\x02\nNds\\Policy\xe2\x02\x16Nds\\Policy\\GPBMetadata\xea\x02\x0bNds::Policyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.policy.policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n5noie.linmimeng.noiedigitalsystem.api.proto.nds.policyB\013PolicyProtoP\001Z*github.com/misty4119/nds-api/Go/nds/policy\242\002\003NPX\252\002\nNds.Policy\312\002\nNds\\Policy\342\002\026Nds\\Policy\\GPBMetadata\352\002\013Nds::Policy'
  _globals['_NDSPOLICY_PARAMSENTRY']._loaded_options = None
  _globals['_NDSPOLICY_PARAMSENTRY']._serialized_options = b'8\001'
  _globals['_NDSPOLICY_METADATAENTRY']._loaded_options = None
  _globals['_NDSPOLICY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_NDSPOLICY']._serialized_start=40
  _globals['_NDSPOLICY']._serialized_end=394
  _globals['_NDSPOLICY_PARAMSENTRY']._serialized_start=276
  _globals['_NDSPOLICY_PARAMSENTRY']._serialized_end=333
  _globals['_NDSPOLICY_METADATAENTRY']._serialized_start=335
  _globals['_NDSPOLICY_METADATAENTRY']._serialized_end=394
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/identity/v1/identity_v1.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/identity/v1/identity_v1.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nds/identity/v1/identity_v1.proto\x12\x0fnds.identity.v1\"!\n\tPersonaId\x12\x14\n\x05value\x18\x01 \x01(\x0cR\x05value\"\xc4\x01\n\x16\x45xternalAccountBinding\x12=\n\x08provider\x18\x01 \x01(\x0e\x32!.nds.identity.v1.ExternalProviderR\x08provider\x12\x1f\n\x0b\x65xternal_id\x18\x02 \x01(\tR\nexternalId\x12%\n\x0everified_level\x18\x03 \x01(\x05R\rverifiedLevel\x12#\n\rbinding_proof\x18\x04 \x01(\x0cR\x0c\x62indingProof\"z\n\x07Persona\x12*\n\x02id\x18\x01 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdR\x02id\x12\x43\n\x08\x62indings\x18\x02 \x03(\x0b\x32\'.nds.identity.v1.ExternalAccountBindingR\x08\x62indings*\xaf\x01\n\x10\x45xternalProvider\x12!\n\x1d\x45XTERNAL_PROVIDER_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45XTERNAL_PROVIDER_MINECRAFT\x10\x01\x12\x1d\n\x19\x45XTERNAL_PROVIDER_DISCORD\x10\x02\x12\x1a\n\x16\x45XTERNAL_PROVIDER_OIDC\x10\x03\x12\x1c\n\x18\x45XTERNAL_PROVIDER_DEVICE\x10\x04\x42\xe7\x01\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.identity.v1B\x0fIdentityV1ProtoP\x01Z:github.com/misty4119/nds-api/Go/nds/identity/v1;identityv1\xa2\x02\x03NIX\xaa\x02\x0fNds.Identity.V1\xca\x02\x0fNds\\Identity\\V1\xe2\x02\x1bNds\\Identity\\V1\\GPBMetadata\xea\x02\x11Nds::Identity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.identity.v1.identity_v1_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n:noie.linmimeng.noiedigitalsystem.api.proto.nds.identity.v1B\017IdentityV1ProtoP\001Z:github.com/misty4119/nds-api/Go/nds/identity/v1;identityv1\242\002\003NIX\252\002\017Nds.Identity.V1\312\002\017Nds\\Identity\\V1\342\002\033Nds\\Identity\\V1\\GPBMetadata\352\002\021Nds::Identity::V1'
  _globals['_EXTERNALPROVIDER']._serialized_start=413
  _globals['_EXTERNALPROVIDER']._serialized_end=588
  _globals['_PERSONAID']._serialized_start=54
  _globals['_PERSONAID']._serialized_end=87
  _globals['_EXTERNALACCOUNTBINDING']._serialized_start=90
  _globals['_EXTERNALACCOUNTBINDING']._serialized_end=286
  _globals['_PERSONA']._serialized_start=288
  _globals['_PERSONA']._serialized_end=410
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/context/context.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/context/context.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19nds/context/context.proto\x12\x0bnds.context\"\xc4\x02\n\nNdsContext\x12\x19\n\x08trace_id\x18\x01 \x01(\tR\x07traceId\x12%\n\x0e\x63orrelation_id\x18\x02 \x01(\tR\rcorrelationId\x12\x1c\n\x07span_id\x18\x03 \x01(\tH\x00R\x06spanId\x88\x01\x01\x12)\n\x0eparent_span_id\x18\x04 \x01(\tH\x01R\x0cparentSpanId\x88\x01\x01\x12\x35\n\x04meta\x18\x05 \x03(\x0b\x32!.nds.context.NdsContext.MetaEntryR\x04meta\x12\x1c\n\ttimestamp\x18\x06 \x01(\x03R\ttimestamp\x1a\x37\n\tMetaEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\n\n\x08_span_idB\x11\n\x0f_parent_span_idB\xc0\x01\n6noie.linmimeng.noiedigitalsystem.api.proto.nds.contextB\x0c\x43ontextProtoP\x01Z+github.com/misty4119/nds-api/Go/nds/context\xa2\x02\x03NCX\xaa\x02\x0bNds.Context\xca\x02\x0bNds\\Context\xe2\x02\x17Nds\\Context\\GPBMetadata\xea\x02\x0cNds::Contextb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.context.context_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n6noie.linmimeng.noiedigitalsystem.api.proto.nds.contextB\014ContextProtoP\001Z+github.com/misty4119/nds-api/Go/nds/context\242\002\003NCX\252\002\013Nds.Context\312\002\013Nds\\Context\342\002\027Nds\\Context\\GPBMetadata\352\002\014Nds::Context'
  _globals['_NDSCONTEXT_METAENTRY']._loaded_options = None
  _globals['_NDSCONTEXT_METAENTRY']._serialized_options = b'8\001'
  _globals['_NDSCONTEXT']._serialized_start=43
  _globals['_NDSCONTEXT']._serialized_end=367
  _globals['_NDSCONTEXT_METAENTRY']._serialized_start=281
  _globals['_NDSCONTEXT_METAENTRY']._serialized_end=336
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/memory/v1/memory.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/memory/v1/memory.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nds.identity.v1 import identity_v1_pb2 as nds_dot_identity_dot_v1_dot_identity__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ands/memory/v1/memory.proto\x12\rnds.memory.v1\x1a!nds/identity/v1/identity_v1.proto\":\n\x04Hash\x12\x1c\n\talgorithm\x18\x01 \x01(\tR\talgorithm\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\"\xc8\x02\n\x0bMemoryProof\x12#\n\x0bproof_tx_id\x18\x01 \x01(\x0cH\x00R\tproofTxId\x88\x01\x01\x12)\n\x0eproof_event_id\x18\x02 \x01(\x0cH\x01R\x0cproofEventId\x88\x01\x01\x12\x36\n\x0c\x63ontent_hash\x18\n \x01(\x0b\x32\x13.nds.memory.v1.HashR\x0b\x63ontentHash\x12\x35\n\tprev_hash\x18\x0b \x01(\x0b\x32\x13.nds.memory.v1.HashH\x02R\x08prevHash\x88\x01\x01\x12\x39\n\x0bmerkle_root\x18\x0c \x01(\x0b\x32\x13.nds.memory.v1.HashH\x03R\nmerkleRoot\x88\x01\x01\x42\x0e\n\x0c_proof_tx_idB\x11\n\x0f_proof_event_idB\x0c\n\n_prev_hashB\x0e\n\x0c_merkle_root\"\xff\x02\n\x0eMemoryArtifact\x12\x0e\n\x02id\x18\x01 \x01(\x0cR\x02id\x12\x30\n\x05owner\x18\x02 \x01(\x0b\x32\x1a.nds.identity.v1.PersonaIdR\x05owner\x12%\n\x0eschema_version\x18\x03 \x01(\x05R\rschemaVersion\x12!\n\tnarrative\x18\n \x01(\tH\x00R\tnarrative\x88\x01\x01\x12 \n\tembedding\x18\x0b \x03(\x02\x42\x02\x10\x01R\tembedding\x12\x30\n\x05proof\x18\x14 \x01(\x0b\x32\x1a.nds.memory.v1.MemoryProofR\x05proof\x12\x1a\n\x08redacted\x18\x1e \x01(\x08R\x08redacted\x12N\n\x10redaction_reason\x18\x1f \x01(\x0e\x32\x1e.nds.memory.v1.RedactionReasonH\x01R\x0fredactionReason\x88\x01\x01\x42\x0c\n\n_narrativeB\x13\n\x11_redaction_reason*\x92\x01\n\x0fRedactionReason\x12 \n\x1cREDACTION_REASON_UNSPECIFIED\x10\x00\x12$\n REDACTION_REASON_PRIVACY_REQUEST\x10\x01\x12\x1b\n\x17REDACTION_REASON_POLICY\x10\x02\x12\x1a\n\x16REDACTION_REASON_LEGAL\x10\x03\x42\xd5\x01\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.memory.v1B\x0bMemoryProtoP\x01Z6github.com/misty4119/nds-api/Go/nds/memory/v1;memoryv1\xa2\x02\x03NMX\xaa\x02\rNds.Memory.V1\xca\x02\rNds\\Memory\\V1\xe2\x02\x19Nds\\Memory\\V1\\GPBMetadata\xea\x02\x0fNds::Memory::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.memory.v1.memory_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8noie.linmimeng.noiedigitalsystem.api.proto.nds.memory.v1B\013MemoryProtoP\001Z6github.com/misty4119/nds-api/Go/nds/memory/v1;memoryv1\242\002\003NMX\252\002\rNds.Memory.V1\312\002\rNds\\Memory\\V1\342\002\031Nds\\Memory\\V1\\GPBMetadata\352\002\017Nds::Memory::V1'
  _globals['_MEMORYARTIFACT'].fields_by_name['embedding']._loaded_options = None
  _globals['_MEMORYARTIFACT'].fields_by_name['embedding']._serialized_options = b'\020\001'
  _globals['_REDACTIONREASON']._serialized_start=858
  _globals['_REDACTIONREASON']._serialized_end=1004
  _globals['_HASH']._serialized_start=80
  _globals['_HASH']._serialized_end=138
  _globals['_MEMORYPROOF']._serialized_start=141
  _globals['_MEMORYPROOF']._serialized_end=469
  _globals['_MEMORYARTIFACT']._serialized_start=472
  _globals['_MEMORYARTIFACT']._serialized_end=855
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/common/common.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/common/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17nds/common/common.proto\x12\nnds.common\"5\n\x07\x44\x65\x63imal\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\x14\n\x05scale\x18\x02 \x01(\x05R\x05scale\"`\n\tNdsResult\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12/\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x14.nds.common.NdsErrorH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"\xb1\x01\n\x08NdsError\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12;\n\x07\x64\x65tails\x18\x03 \x03(\x0b\x32!.nds.common.NdsError.DetailsEntryR\x07\x64\x65tails\x1a:\n\x0c\x44\x65tailsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x83\x01\n\x08Metadata\x12;\n\x07\x65ntries\x18\x01 \x03(\x0b\x32!.nds.common.Metadata.EntriesEntryR\x07\x65ntries\x1a:\n\x0c\x45ntriesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xce\x04\n\tErrorCode\x12\x1a\n\x16\x45RROR_CODE_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x45RROR_CODE_ASSET_NOT_FOUND\x10\x01\x12#\n\x1f\x45RROR_CODE_ASSET_ALREADY_EXISTS\x10\x02\x12#\n\x1f\x45RROR_CODE_INSUFFICIENT_BALANCE\x10\x03\x12#\n\x1f\x45RROR_CODE_ASSET_LIMIT_EXCEEDED\x10\x04\x12!\n\x1d\x45RROR_CODE_IDENTITY_NOT_FOUND\x10\n\x12\x1f\n\x1b\x45RROR_CODE_IDENTITY_INVALID\x10\x0b\x12!\n\x1d\x45RROR_CODE_TRANSACTION_FAILED\x10\x14\x12&\n\"ERROR_CODE_TRANSACTION_ROLLED_BACK\x10\x15\x12$\n ERROR_CODE_CONSISTENCY_VIOLATION\x10\x16\x12%\n!ERROR_CODE_SYSTEM_NOT_INITIALIZED\x10\x1e\x12\x1b\n\x17\x45RROR_CODE_SYSTEM_ERROR\x10\x1f\x12\x16\n\x12\x45RROR_CODE_TIMEOUT\x10 \x12\x1f\n\x1b\x45RROR_CODE_INVALID_ARGUMENT\x10(\x12 \n\x1c\x45RROR_CODE_PERMISSION_DENIED\x10)\x12\x1f\n\x1b\x45RROR_CODE_POLICY_VIOLATION\x10*\x12!\n\x1d\x45RROR_CODE_RATIONALE_REQUIRED\x10+B\xb9\x01\n5noie.linmimeng.noiedigitalsystem.api.proto.nds.commonB\x0b\x43ommonProtoP\x01Z*github.com/misty4119/nds-api/Go/nds/common\xa2\x02\x03NCX\xaa\x02\nNds.Common\xca\x02\nNds\\Common\xe2\x02\x16Nds\\Common\\GPBMetadata\xea\x02\x0bNds::Commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.common.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n5noie.linmimeng.noiedigitalsystem.api.proto.nds.commonB\013CommonProtoP\001Z*github.com/misty4119/nds-api/Go/nds/common\242\002\003NCX\252\002\nNds.Common\312\002\nNds\\Common\342\002\026Nds\\Common\\GPBMetadata\352\002\013Nds::Common'
  _globals['_NDSERROR_DETAILSENTRY']._loaded_options = None
  _globals['_NDSERROR_DETAILSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_ENTRIESENTRY']._loaded_options = None
  _globals['_METADATA_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_ERRORCODE']._serialized_start=507
  _globals['_ERRORCODE']._serialized_end=1097
  _globals['_DECIMAL']._serialized_start=39
  _globals['_DECIMAL']._serialized_end=92
  _globals['_NDSRESULT']._serialized_start=94
  _globals['_NDSRESULT']._serialized_end=190
  _globals['_NDSERROR']._serialized_start=193
  _globals['_NDSERROR']._serialized_end=370
  _globals['_NDSERROR_DETAILSENTRY']._serialized_start=312
  _globals['_NDSERROR_DETAILSENTRY']._serialized_end=370
  _globals['_METADATA']._serialized_start=373
  _globals['_METADATA']._serialized_end=504
  _globals['_METADATA_ENTRIESENTRY']._serialized_start=446
  _globals['_METADATA_ENTRIESENTRY']._serialized_end=504
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nds/event/event.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'nds/event/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from nds.identity import identity_pb2 as nds_dot_identity_dot_identity__pb2
from nds.context import context_pb2 as nds_dot_context_dot_context__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15nds/event/event.proto\x12\tnds.event\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bnds/identity/identity.proto\x1a\x19nds/context/context.proto\"\x1f\n\x07\x45ventId\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\"9\n\nNdsPayload\x12+\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x64\x61ta\"\xde\x03\n\x08NdsEvent\x12\"\n\x02id\x18\x01 \x01(\x0b\x32\x12.nds.event.EventIdR\x02id\x12;\n\x0boccurred_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12/\n\x05\x61\x63tor\x18\x03 \x01(\x0b\x32\x19.nds.identity.NdsIdentityR\x05\x61\x63tor\x12(\n\x04type\x18\x04 \x01(\x0e\x32\x14.nds.event.EventTypeR\x04type\x12/\n\x07payload\x18\x05 \x01(\x0b\x32\x15.nds.event.NdsPayloadR\x07payload\x12%\n\x0eschema_version\x18\x06 \x01(\x05R\rschemaVersion\x12=\n\x08metadata\x18\x07 \x03(\x0b\x32!.nds.event.NdsEvent.MetadataEntryR\x08metadata\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32\x17.nds.context.NdsContextH\x00R\x07\x63ontext\x88\x01\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\n\n\x08_context*\x8d\x02\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45VENT_TYPE_TRANSACTION\x10\x01\x12\x1c\n\x18\x45VENT_TYPE_ASSET_CREATED\x10\x02\x12\x1c\n\x18\x45VENT_TYPE_ASSET_UPDATED\x10\x03\x12\x1c\n\x18\x45VENT_TYPE_ASSET_DELETED\x10\x04\x12\x1f\n\x1b\x45VENT_TYPE_IDENTITY_CREATED\x10\x05\x12\x1f\n\x1b\x45VENT_TYPE_IDENTITY_UPDATED\x10\x06\x12\x15\n\x11\x45VENT_TYPE_SYSTEM\x10\x07\x12\x15\n\x11\x45VENT_TYPE_CUSTOM\x10\x63\x42\xb2\x01\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.eventB\nEventProtoP\x01Z)github.com/misty4119/nds-api/Go/nds/event\xa2\x02\x03NEX\xaa\x02\tNds.Event\xca\x02\tNds\\Event\xe2\x02\x15Nds\\Event\\GPBMetadata\xea\x02\nNds::Eventb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nds.event.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4noie.linmimeng.noiedigitalsystem.api.proto.nds.eventB\nEventProtoP\001Z)github.com/misty4119/nds-api/Go/nds/event\242\002\003NEX\252\002\tNds.Event\312\002\tNds\\Event\342\002\025Nds\\Event\\GPBMetadata\352\002\nNds::Event'
  _globals['_NDSEVENT_METADATAENTRY']._loaded_options = None
  _globals['_NDSEVENT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_EVENTTYPE']._serialized_start=729
  _globals['_EVENTTYPE']._serialized_end=998
  _globals['_EVENTID']._serialized_start=155
  _globals['_EVENTID']._serialized_end=186
  _globals['_NDSPAYLOAD']._serialized_start=188
  _globals['_NDSPAYLOAD']._serialized_end=245
  _globals['_NDSEVENT']._serialized_start=248
  _globals['_NDSEVENT']._serialized_end=726
  _globals['_NDSEVENT_METADATAENTRY']._serialized_start=655
  _globals['_NDSEVENT_METADATAENTRY']._serialized_end=714
# @@protoc_insertion_point(module_scope)
